"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatresponse import ChatResponse, ChatResponseTypedDict
from .chatstreamingresponsechunk import (
    ChatStreamingResponseChunkData,
    ChatStreamingResponseChunkDataTypedDict,
)
from openrouter.utils import eventstreaming
from typing import Union
from typing_extensions import TypeAliasType


SendChatCompletionRequestResponseTypedDict = TypeAliasType(
    "SendChatCompletionRequestResponseTypedDict",
    Union[
        ChatResponseTypedDict,
        Union[
            eventstreaming.EventStream[ChatStreamingResponseChunkDataTypedDict],
            eventstreaming.EventStreamAsync[ChatStreamingResponseChunkDataTypedDict],
        ],
    ],
)


SendChatCompletionRequestResponse = TypeAliasType(
    "SendChatCompletionRequestResponse",
    Union[
        ChatResponse,
        Union[
            eventstreaming.EventStream[ChatStreamingResponseChunkData],
            eventstreaming.EventStreamAsync[ChatStreamingResponseChunkData],
        ],
    ],
)
