"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .publicendpoint import PublicEndpoint, PublicEndpointTypedDict
from openrouter.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListEndpointsZdrResponseTypedDict(TypedDict):
    r"""Returns a list of endpoints"""

    data: List[PublicEndpointTypedDict]


class ListEndpointsZdrResponse(BaseModel):
    r"""Returns a list of endpoints"""

    data: List[PublicEndpoint]
