"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


OpenAIResponsesTruncation = Union[
    Literal[
        "auto",
        "disabled",
    ],
    UnrecognizedStr,
]
